@@ -25,16 +25,17 @@ file chooser (see also :ref:`application flow`)::
 The variable `open_button` in this example represents a button widget instance that opens the file chooser dropdown (and
 to which the file chooser gets attached to).
 
-If the file chooser has multiple usages in the app, then the :attr:`~FileChooserPopup.submit_to` property can be
-used for to distribute the selected file path to the correct usage/process::
+Use the :attr:`~FileChooserPopup.submit_to` property to distinguish multiple usages of the file chooser in a single
+app::
 
     main_app.change_flow(id_of_flow('open', 'file_chooser'),
                          **update_tap_kwargs(open_button,
                                              popup_kwargs=dict(submit_to=submit_to_str_or_callable))
 
-`submit_to_str_or_callable` can be either a string or a callable. If you pass a callable then :class:`FileChooserPopup`
-will call it if the user has selected a file (by touching or double clicking on a file entry). This callback receives
-two arguments: the file path of just selected file and the dropdown widget instance an and can be declared like::
+The variable `submit_to_str_or_callable` of the above example can be either a string or a callable. If you pass a
+callable, :class:`FileChooserPopup` will call it if the user has selected a file (by touching or double clicking on a
+file entry). This callback receives two arguments: the file path of just selected file and the :class:`FileChooser`
+dropdown widget instance an and can be declared like::
 
     def submit_to_callable(file_path: str, chooser_popup: Widget):
 
@@ -47,19 +48,33 @@ handler callback method of your main app instance will be executed with the same
             chooser_popup.dismiss()
         elif chooser_popup.submit_to == 'usage2':
             ...
+        elif chooser_popup.submit_to == '':     # w/o specifying `submit_to`
+            ...
 
-This file chooser is providing all common OS and user paths as well as app specific paths that are maintained in the
-:data:`~ae.paths.PATH_PLACEHOLDERS` dict. The keys of this dict will be displayed as shortcut path names instead of the
-full path strings. Additionally translation texts can be provided for the shortcut path names for to display them in the
-language selected by the app user.
+Use the key of the :attr:`~ae.kivy_app.FlowButton.tap_flow_id` property of the :class:`~ae.kivy_app.FlowButton` to
+provide a separate i18n help text for each individual button.
 
-By adding the list `file_chooser_paths` to the `:ref:`app state variables` of your app, this file chooser widget will
-automatically maintain and keep the last/historical path selections of the file chooser persistent between app runs.
+The :attr:`~FileChooserPopup.filters` property of Kivy's :class:`kivy.uix.filechooser.FileChooser` can be used
+to filter the files displayed in this file chooser widget.
+
+The path selector dropdown (:class:`FileChooserPathSelectPopup`) situated at the top of this file chooser dropdown
+is providing all common OS and app specific paths that are registered in the :data:`~ae.paths.PATH_PLACEHOLDERS` dict.
+The keys of this dict will be displayed as shortcut path names instead of the full path strings. Additionally
+translation texts can be provided for the shortcut path names for to display them in the language selected by the app
+user.
+
+To extend the path selector dropdown with additional paths you can either register them within
+:data:`~ae.paths.PATH_PLACEHOLDERS`, or you add them to the optional app state variable `file_chooser_paths` by calling
+the method :meth:`~FileChooserPopup.register_file_path`.
+
+By adding the list `file_chooser_paths` to the `:ref:`app state variables` of your app, the paths provided by the path
+selector widget will automatically maintain and keep the OS and user paths persistent between app runs.
 
 For to record and remember the last selected path add also the app state `file_chooser_initial_path` to the
 `:ref:`app state variables` of your app.
 """
-from typing import List
+import os
+from typing import Any, List
 
 from kivy.app import App                                    # type: ignore
 from kivy.lang import Builder                               # type: ignore
@@ -70,7 +85,7 @@ from kivy.uix.widget import Widget                          # type: ignore
 from ae.kivy_app import FlowDropDown                        # type: ignore
 
 
-__version__ = '0.1.5'
+__version__ = '0.1.7'
 
 
 Builder.load_string('''\
@@ -79,7 +94,7 @@ Builder.load_string('''\
     do_scroll_x: True
     do_scroll_y: False
     on_initial_path: app.main_app.change_app_state('file_chooser_initial_path', self.initial_path)
-    auto_width_minimum: min(Window.width * 0.96, app.app_states['font_size'] * 21)
+    auto_width_minimum: min(Window.width * 0.96, app.app_states['font_size'] * 24)
     BoxLayout:
         size_hint_y: None
         height: app.app_states['font_size'] * 1.8
@@ -105,14 +120,13 @@ Builder.load_string('''\
     FileChooser:
         id: chooser_widget
         path: root.initial_path
+        filters: root.filters
         size_hint_y: None
         height: (root.attach_to.top if root.attach_to else Window.height) * 0.96 - app.main_app.font_size * 3.0
-        on_submit:
-            (root.submit_to if callable(root.submit_to) else app.main_app.on_file_chooser_submit)(args[1][0], root)
         multiselect: True
         on_selection:
-            if args[1]: \
-            (root.submit_to if callable(root.submit_to) else app.main_app.on_file_chooser_submit)(args[1][0], root)
+            args[1] and \
+            (root.submit_to if callable(root.submit_to) else app.main_app.on_file_chooser_submit)(args[1][-1], root)
         on_entry_added: root.on_file_chooser_entry_added(args[1])
         on_subentry_to_entry: root.on_file_chooser_entry_added(args[1])
         FileChooserListLayout
@@ -137,6 +151,7 @@ class FileChooserPopup(FlowDropDown):
     """ file chooser drop down container. """
     initial_path = StringProperty()     #: initial file path displayed on opening
     submit_to = ObjectProperty("")      #: callable or string to identify which action/part requested the selected file
+    filters = ListProperty()            #: see :attr:`kivy.uix.filechooser.FileChooser.filters`.
 
     @staticmethod
     def on_file_chooser_entry_added(view_entries: List[Widget]):                                # pragma: no cover
@@ -177,6 +192,19 @@ class FileChooserPopup(FlowDropDown):
                 entry.children[0].color = font_color if light_theme else [0.81, 0.81, 0.81, 1.0]
                 entry.children[0].font_size = min(entry.children[0].height * 0.90, font_size)
 
+    @staticmethod
+    def register_file_path(file_path: str, main_app: Any):
+        """ set folder of the passed file path as new initial path and add it to path history.
+
+        :param file_path:       file path (mostly the last just selected file) of which the folder will be registered.
+        :param main_app:        main app instance.
+        """
+        folder = os.path.abspath(os.path.dirname(file_path))
+        main_app.change_app_state('file_chooser_initial_path', folder)
+        if folder not in main_app.file_chooser_paths:
+            main_app.file_chooser_paths.insert(0, folder)
+            main_app.change_app_state('file_chooser_paths', main_app.file_chooser_paths)
+
 
 class FileChooserPathSelectPopup(FlowDropDown):
     """ file chooser path selector dropdown. """
